@@ -6,7 +6,7 @@
 #ifndef LIST_SORT_H
 #define LIST_SORT_H
 
-#include <cbtcommon/list.h>
+#include "list.h"
 
 void list_sort(struct list_head *, int (*)(struct list_head *, struct list_head *));
 
